;; Generated package description from embark-consult.el  -*- no-byte-compile: t -*-
(define-package "embark-consult" "0.7" "Consult integration for Embark" '((emacs "27.1") (embark "0.20") (consult "0.17")) :commit "127492fac048cecfdba145d496a902022a68d1d5" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("convenience") :url "https://github.com/oantolin/embark")
